@@ -11,6 +11,7 @@ from allianceauth.services.hooks import MenuItemHook, UrlHook
 
 # AA Time Zones
 from timezones import __title__, urls
+from timezones.app_settings import allianceauth_discordbot_active
 
 
 class AaTimezonesMenuItem(MenuItemHook):  # pylint: disable=too-few-public-methods
@@ -54,3 +55,15 @@ def register_urls():
     :return:
     """
     return UrlHook(urls, "timezones", r"^timezones/")
+
+
+# Only register the cog when aadiscordbot is installed
+if allianceauth_discordbot_active():
+
+    @hooks.register("discord_cogs_hook")
+    def register_cogs():
+        """
+        Registering our discord cog
+        """
+
+        return ["timezones.aadiscordbot.cogs.time"]
